@@ -82,7 +82,10 @@ public:
 
     virtual bool hasIntersectMethods() const { return true; }
 
-private:
+protected:
+
+	BlockMgr *_splitBlockMgr;
+
 	virtual bool handle_a();
 	virtual bool handle_abam();
 	virtual bool handle_b();
